@@ -2,7 +2,7 @@ import os
 import json
 from pydash import get, pick
 from reactivex import Observable, operators as ops
-from aws_lambda_stream.connectors.elasticsearch import Connector
+from aws_lambda_stream.connectors.opensearch import Connector
 from aws_lambda_stream.utils.json_encoder import JSONEncoder
 from aws_lambda_stream.utils.operators import split_buffer, rx_map
 from aws_lambda_stream.utils.faults import faulty
@@ -12,8 +12,7 @@ from .batch import to_batch_uow, unbatch_uow
 def update_elasticsearch(
     connector: Connector,
     update_field='update_request',
-    batch_size=os.getenv('PUBLISH_BATCH_SIZE') or os.getenv('BATCH_SIZE') or 10,
-    max_batch_size=os.getenv('PUBLISH_BATCH_SIZE') or os.getenv('BATCH_SIZE') or 10,
+    batch_size=os.getenv('PUBLISH_BATCH_SIZE') or os.getenv('BATCH_SIZE') or 10
 ):
     def to_input_params(batch_uow):
         return {
@@ -41,7 +40,7 @@ def update_elasticsearch(
         }
     def wrapper(source: Observable):
         return source.pipe(
-            ops.buffer_with_count(max_batch_size if batch_size > max_batch_size else batch_size),
+            ops.buffer_with_count(batch_size, batch_size),
             rx_map(to_batch_uow),
             rx_map(to_input_params),
             rx_map(faulty(put_items)),
